@@ -19,7 +19,7 @@ def search():
             index_page.submit_keyword(kw)
             res = index_page.get_search_result()
             c_content.update(kw, res)
-            if c_content.analyse:
+            if c_content.analyse != '':
                 c_content.extract_tags()
             c_content.export()
         index_page.driver.quit()
