@@ -19,7 +19,7 @@ class SearchContent:
     @classmethod
     def user_input(cls):
         while 1:
-            import_file = input('请输入文件名')
+            import_file = input('请输入导入文件名，支持txt/xlsx')
             if os.path.exists(import_file) and import_file.split('.')[-1] in ['txt', 'csv', 'xlsx']:
                 break
             else:
